<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>MX Service Manager</source>
        <translation>MX Service-Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <location filename="../mainwindow.cpp" line="157"/>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>&amp;Enable at boot</source>
        <translation>&amp;Beim Systemstart aktivieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>About this application</source>
        <translation>Über diese Anwendung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>&amp;About...</source>
        <translation>&amp;Über...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="71"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <source>Display help </source>
        <translation>Hilfe anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="128"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="166"/>
        <source>Quit application</source>
        <translation>Anwendung beenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="175"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="216"/>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>All services</source>
        <translation>Alle Dienste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>Running services</source>
        <translation>Laufende Dienste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <location filename="../mainwindow.cpp" line="321"/>
        <source>Services enabled at boot</source>
        <translation>Beim Systemstart aktivierte Dienste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>Services disabled at boot</source>
        <translation>Beim Systemstart deaktivierte Dienste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>search</source>
        <translation>Suche </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="291"/>
        <location filename="../mainwindow.cpp" line="68"/>
        <location filename="../mainwindow.cpp" line="76"/>
        <location filename="../mainwindow.cpp" line="80"/>
        <source>Loading...</source>
        <translation>Lade…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
        <translation>Dieses Werkzeug listet Dienste und Daemons (Prozesse, die im Hintergrund laufen) auf, die auf diesem System gefunden wurden. Achten Sie darauf, nichts zu stoppen, was eine kritische Komponente stören könnte; am besten lassen Sie es in Ruhe, wenn Sie nicht wissen, was es ist.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="62"/>
        <location filename="../mainwindow.cpp" line="392"/>
        <location filename="../mainwindow.cpp" line="399"/>
        <location filename="../mainwindow.cpp" line="420"/>
        <location filename="../mainwindow.cpp" line="429"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="63"/>
        <source>Could not determine the init system. This program is supposed to run either with systemd or sysvinit</source>
        <translation>Das init-System konnte nicht ermittelt werden. Dieses Programm sollte entweder mit systemd oder sysvinit laufen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>S&amp;tart</source>
        <translation>S&amp;tart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="150"/>
        <source>&amp;Disable at boot</source>
        <translation>&amp;Beim Systemstart deaktivieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="355"/>
        <source>%1 total services, %2 currently &lt;font color=&apos;%3&apos;&gt;running&lt;/font&gt;</source>
        <translation>%1 Dienste insgesamt, %2 derzeit &lt;font color=&apos;%3&apos;&gt;laufend&lt;/font&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>%1 &lt;font color=&apos;%2&apos;&gt;enabled&lt;/font&gt; at boot, but not running</source>
        <translation>%1 &lt;font color=&apos;%2&apos;&gt;aktiviert&lt;/font&gt; beim Startvorgang, aber derzeit nicht laufend</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>About %1</source>
        <translation>Über %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>Service and daemon manager</source>
        <translation>Dienst- und Daemonmanager</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="379"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="380"/>
        <source>%1 License</source>
        <translation>%1 Lizenz</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>Could not enable %1</source>
        <translation>Konnte %1 nicht aktivieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <location filename="../mainwindow.cpp" line="403"/>
        <location filename="../mainwindow.cpp" line="425"/>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Success</source>
        <translation>Erfolg</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>%1 was enabled at boot time.</source>
        <translation>%1 wurde für den Startvorgang aktiviert.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="399"/>
        <source>Could not disable %1</source>
        <translation>Konnte %1 nicht deaktivieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>%1 was disabled.</source>
        <translation>%1 wurde deaktiviert.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="410"/>
        <source>%1 Help</source>
        <translation>%1 Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>Could not start %1</source>
        <translation>%1 konnte nicht gestartet werden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>%1 was started.</source>
        <translation>%1 wurde gestartet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="429"/>
        <source>Could not stop %1</source>
        <translation>%1 konnte nicht angehalten werden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>%1 was stopped.</source>
        <translation>%1 wurde angehalten.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Änderungsprotokoll</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Sie sind als Administrator am System angemeldet. Bitte melden Sie sich ab und dann als normaler Benutzer wieder an, um dieses Programm zu verwenden.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>Diese Anwendung muss mit Administratorrechten ausgeführt werden.</translation>
    </message>
    <message>
        <location filename="../service.cpp" line="124"/>
        <source>Could not find service description</source>
        <translation>Eine Beschreibung des Dienstes konnte nicht gefunden werden</translation>
    </message>
</context>
</TS>